﻿/****************************************************************************
*
*             Copyright (C) FarSite Communications Ltd. 2020
*                             All Rights Reserved
*
* License is granted to copy and use this software and to make and
* use derivative works.
*
* FarSite Communications Limited makes no representations concerning 
* either the merchantability of this software or the suitability of 
* this software for any particular purpose. It is provided "as is"
* without express or implied warranty of any kind.
*
* Program     : fsbert
*                                                                 
* File        : Program.cs
*                                                                 
* Version     : V1.0.0
*                                                                   
* Description : Sample C# program using the FarSync BERT API via
*               the FSBERTIFLib2 interop-based class
*
*
* Modifications
*
* Date      Init   Details
*
* 12Oct0    WEB    Initial version
*
****************************************************************************/

using System;
using System.Threading; 
using FSBERTIFLib2;

using static System.Console;

namespace fsbert
{
    class Program
    {
        static void displayStats(FsBert2 bert)
        {
            // display the current stats, of the supplied BERT object, on the console

            WriteLine("Duration(s):{0:F3}", bert.Duration/1000000); // convert from usecs to secs
            WriteLine("RxBitCount:{0:F0} BlockCount:{1:F0} RxRate(bps):{2:F0}", bert.BitCount, bert.BlockCount, bert.BitRate);
            WriteLine("BitErr:{0:F0} BlockErr:{1:F0} ES(US):{2:F0} SES:{3:F0} AS:{4:F0}", bert.BitErrorCount, bert.BlockErrorCount, bert.ESCount, bert.SESCount, bert.ASCount);
            WriteLine("BER:{0:E3} ESR:{1:E3} SESR:{2:E3} ASR:{3:E3}", bert.BitErrorRate, bert.ESRate, bert.ESRate, bert.ASRate);
            WriteLine("LOSCount:{0:F0} LOSRate:{1:E3}", bert.LOSCount, bert.LOSRate);
            WriteLine("");
        }

        static void Main(string[] args)
        {
            WriteLine("fsbert C# sample - fsbert V1.0.0");
            WriteLine("(C) FarSite Communications Ltd. 2020");
            WriteLine();

            // create the FarSync BERT API object
            FsBert2 bert = new FsBert2();

            // setup its configuration and signal state (before running the test)
            bert.DTR = true;
            bert.Device = 0;
            bert.Port = 0;
            bert.Rate = 9600;
            bert.Interface = FsBertInterfaceConstants.FsBertInterface_V24;
            bert.Clocking = FsBertClockingConstants.FsBertClocking_Internal;
            bert.Pattern = FsBertPatternConstants.FsBertPattern_2_15;
            bert.TestLength = 0;
            //bert.debugMode = 2;  // enable this to display the BERT engine's console while it's in use

            // start the FarSync BERT
            bert.Start();

            // display the current stats from the FarSync BERT, once every second
            do
            {
                while (!Console.KeyAvailable)
                {
                    Thread.Sleep(1000);
                    displayStats(bert);
                }
            } while (Console.ReadKey(true).Key != ConsoleKey.Escape);

            // now stop the FarSync BERT
            bert.Stop();

            // and wait for it to stop before we exit
            while (bert.Status != FsBertStatusConstants.FsBertStatus_Stopped)
            {
                Thread.Sleep(100);
            }
        }
    }

}

