#############################################################################
#
#             Copyright (C) FarSite Communications Ltd. 2020
#                             All Rights Reserved
#
# License is granted to copy and use this software and to make and
# use derivative works.
#
# FarSite Communications Limited makes no representations concerning 
# either the merchantability of this software or the suitability of 
# this software for any particular purpose. It is provided "as is"
# without express or implied warranty of any kind.
#
# Program     : fsbert
#                                                                 
# File        : main.py
#                                                                 
# Version     : V1.0.0
#                                                                   
# Description : Sample python program using the FarSync BERT API via
#               the FsBert class (in fsbert.py)
#
# Modifications
#
# Date      Init   Details
#
# 12Oct20   WEB    Initial version
#
#############################################################################

import time
import fsbert

# setup the required configuration for use when running the FarSync BERT
print()
print("fsbert python sample - fsbert V1.0.0")
print("(C) FarSite Communications Ltd. 2020")
print()
print ("setting configuration")
device = 0
port = 0
internal_clocking = True

# create the FarSync BERT API object
print ("creating")
bert = fsbert.FsBert(device, port, internal_clocking, 9600)

# set the required state of the output signals
print ("setting signals")
bert.DTR = True
bert.RTS = True

# start the FarSync BERT
print ("starting")
bert.start()

# wait for it to start
while (bert.status != bert.consts.FsBertStatus_Started):
    time.sleep(1)
print ("started")

# leave it running for 10s
time.sleep(10)

#Note: uncomment this to see the effect of (intentionally) injecting errors
#print ("inject error")
#bert.inject_errors(1)
#time.sleep(5)

# now stop the FarSync BERT
print ("stopping")
bert.stop()
print ("stopped")

# print (a subset of) the results
print()
print ("  BitCount:"+str(int(bert.bit_count)))
print ("  BER:"+str(bert.bit_error_rate))
print()

# finally, delete the FarSync BERT API object
print ("deleting")
del bert
print ("deleted")
print()


